@@ -1,41 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 Klaralvdalens Datakonsult AB (KDAB).
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the Qt3D module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 Klaralvdalens Datakonsult AB (KDAB).
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 #include "qrendersettings.h"
 #include "qrendersettings_p.h"
@@ -67,7 +31,7 @@ namespace Qt3DRender {
    \l{Qt 3D Render Framegraph}{FrameGraph}.
    \since 5.7
    \inqmlmodule Qt3D.Render
-   \instantiates Qt3DRender::QRenderSettings
+   \nativetype Qt3DRender::QRenderSettings
 
    The RenderSettings component must be set as a component of the scene root entity. It specifies
    render policy and picking settings, as well as hosts the active
@@ -151,7 +115,7 @@ QRenderSettings::~QRenderSettings()
     \since 5.15
 */
 /*!
-    \property QRenderSettings::renderCapabilities
+    \property Qt3DRender::QRenderSettings::renderCapabilities
 
     Holds the details of the supported rendering engine
 
@@ -172,7 +136,7 @@ QRenderCapabilities *QRenderSettings::renderCapabilities()
     \readonly
 */
 /*!
-    \property QRenderSettings::pickingSettings
+    \property Qt3DRender::QRenderSettings::pickingSettings
 
     Holds the current pick settings for the \l{Qt 3D Render Framegraph}{FrameGraph}.
 
@@ -190,7 +154,7 @@ QPickingSettings *QRenderSettings::pickingSettings()
     Holds the currently active \l{Qt 3D Render Framegraph}{FrameGraph}.
 */
 /*!
-    \property QRenderSettings::activeFrameGraph
+    \property Qt3DRender::QRenderSettings::activeFrameGraph
 
     Holds the currently active \l{Qt 3D Render Framegraph}{FrameGraph}.
 */
@@ -202,7 +166,7 @@ QFrameGraphNode *QRenderSettings::activeFrameGraph() const
 
 
 /*!
-    \enum QRenderSettings::RenderPolicy
+    \enum Qt3DRender::QRenderSettings::RenderPolicy
 
     The render policy.
 
@@ -225,7 +189,7 @@ QFrameGraphNode *QRenderSettings::activeFrameGraph() const
     \sa Qt3DRender::QRenderSettings::RenderPolicy
 */
 /*!
-    \property QRenderSettings::renderPolicy
+    \property Qt3DRender::QRenderSettings::renderPolicy
 
     Holds the current render policy.
 */
@@ -277,20 +241,6 @@ void QRenderSettings::setRenderPolicy(QRenderSettings::RenderPolicy renderPolicy
     emit renderPolicyChanged(renderPolicy);
 }
 
-Qt3DCore::QNodeCreatedChangeBasePtr QRenderSettings::createNodeCreationChange() const
-{
-    auto creationChange = Qt3DCore::QNodeCreatedChangePtr<QRenderSettingsData>::create(this);
-    auto &data = creationChange->data;
-    Q_D(const QRenderSettings);
-    data.activeFrameGraphId = qIdForNode(d->m_activeFrameGraph);
-    data.renderPolicy = d->m_renderPolicy;
-    data.pickMethod = d->m_pickingSettings.pickMethod();
-    data.pickResultMode = d->m_pickingSettings.pickResultMode();
-    data.faceOrientationPickingMode = d->m_pickingSettings.faceOrientationPickingMode();
-    data.pickWorldSpaceTolerance = d->m_pickingSettings.worldSpaceTolerance();
-    return creationChange;
-}
-
 } // namespace Qt3Drender
 
 QT_END_NAMESPACE
